/*
 * $Id: YearMonthDayModifiedPreceedingHandler.java 173 2006-09-13 15:08:18Z benoitx $
 * 
 * Copyright 2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package net.objectlab.kit.datecalc.joda;

import net.objectlab.kit.datecalc.common.DateCalculator;
import net.objectlab.kit.datecalc.common.HolidayHandlerType;

import org.joda.time.YearMonthDay;

/**
 * A modified preceeding handler will move the date backward if it falls on a
 * non working day BUT, if the new date falls into another month, it will revert
 * to moving forward until it finds a working day.
 * 
 * @author Benoit Xhenseval
 * @author $LastChangedBy: benoitx $
 * @version $Revision: 173 $ $Date: 2006-09-13 16:08:18 +0100 (Wed, 13 Sep 2006) $
 * 
 */
public class YearMonthDayModifiedPreceedingHandler extends YearMonthDayModifiedFollowingHandler {

    /**
     * If the current date of the give calculator is a non-working day, it will
     * be moved according to the algorithm implemented.
     * 
     * @param calculator
     *            the calculator
     * @return the date which may have moved.
     */
    @Override
    public YearMonthDay moveCurrentDate(final DateCalculator<YearMonthDay> calculator) {
        return move(calculator, -1);
    }

    /**
     * Give the type name for this algorithm.
     * 
     * @return algorithm name.
     */
    @Override
    public String getType() {
        return HolidayHandlerType.MODIFIED_PRECEEDING;
    }
}
